pub struct CapitalGain {
pub amount: f64,
pub date: i64,
}Expand description
This structure simply models a capital gain which has been recorded.
Fields
amount: f64This is the amount of capital gain distributed by the fund
date: i64This is the recorded date of the capital gain